### intro to programming in R
### data expeditions Novemeber 2017

# Goals today:
#	-maybe learn a little something about stable isotope ecology
# 	-get some general tools for manipulating and visualizing datasets
#	-we are mostly going to use R
#		-R is a programming language (more on that later)
#		-it was specially designed to be useful for statistics and data but like most programming languages you can write a program in R to do almost anything you like.	
#		-it's free
#		-it runs on many types of hardware
#		-there is lots of good support for it online

### programming

# What is a programming language? (everyone write down what they think for 2 min)
# 	-most basically a formalized way of writing down instructions for a computer
#	-usually has some vocabulary or basic key words and syntax, rules for putting them together

# What do you need in a programming language (especially one that might be useful for statistics
#	-representations of data
#	-ways of transforming that data
# 	-syntax or systematic rules for defining instructions

### What we are going to do? Go through those first two components one by one and pick up the syntax along the way
# first let's open up R and see what we got.
# console - this is where the magic happens
# source window - this is where you should generally write your code so that it is reproducible.
# start a new source window.
# the pound sign denotes a comment. this is ignored by R and serves as notes to you. use them or you will forget what you did later. or if you publish something you need to be able to give your code to someone else and have them understand it (within reason).

1
1+2
1:3
c(1, 2, 3)
one <- 1
two <- 2
one + two
vec1 <- c(1, 2, 3)
vec1

# c means combine and can be used to manually combine numbers into a vector
# <- means assign the value on the right to the variable name on the left
# r is very flexible -> means assign the value on the left to the variable name on the right or you can also use the equals sign

c(4, 5, 6) -> vec2
vec3 = c(7, 8, 9)

# let's start with a simple representation of data a vector of length 3.
# [] [] []. Can think of these are little reserved boxes in the computers memory that we can put information in.
# can fill with numbers: [1] [2] [3] or characters ["a"] ["b"] ["c"] or booleans [TRUE] [TRUE] [FALSE]

vec4 <- c("a", "b", "c")
vec5 <- c(TRUE, TRUE, FALSE)



# what do we need to know to use this vector?
#	-an address
#	-an index

#the address is usually a long number (obviously hard to intepret). R let's us save the address conveniently in an english word (vec1, vec2, vec3).

#now for indexing. when we type vec1 R "returns" the whole vector. what if we only want the second position?

vec1[2]
vec1[-2]


#the square brackets mean look for the address stored in vec1 in memory and then count 1,2 and give me just what is sitting in that box in memory [] [THIS ONE!] []


### functions

#I've cheated and we've actually already used at least 3 functions. one is the assignment function <- or -> or =. And it is very basic to R. another is + which as you might expect takes two values and adds them together. finally we have c which looks more like a regular function. functions consist of a name -- c and smooth brackets () in between which go the parameters. some functions take no parameters, some take many.

#here are some useful functions.

x <- c(1.8, 2.2, 3.1, 2.3)
sum(x)
length(x)
mean(x)
sum(x) / length(x)


# let's write our own function
# like vectors we have to store a function in a variable name so R knows where to find the representation in memory. unlike vectors the representation will be more complicated than just storing numbers because we are storing instructions, but we don't have to get into the details of how that works to use it.

my_mean <- function(xvec) {
	sum(xvec) / length(xvec)
}

my_mean(x)
my_mean(c(1, 2))
my_mean(xvec = x)
my_mean(xvec <- c(1, 1, 2, 2))

my_mean(x) == mean(x) #notice two equals when we are doing a comparison

# when we define a function we use the keyword function and then place parameters inside. these will be the internal (local) names of any data we want to pass to the function. Functions are little universes that are created when a function gets "called" and collapse into nothing when they complete (get to that second curly brace). R is a smart programming language and all of the memory that it has allocated for running that function gets "garbage collected" when we're done with it while retaining the generic instructions we saved under the name "my_mean". sometimes R messes up garabage collection and keeps eating up more and more memory until it crashes.

# the take away is that anything created or manipulated inside a function will self destruct at the end of the function EXCEPT for the very last line (we only have one line in our example). That last line gets thrown back up to whoever called the function (could be us typing in the console... could be another function). Let's take a closer look. sum and length are both functions. They did their work and threw the result back up or "returned" their value just up to the next level that called them which was our function "my_mean".

# let's make this function a little more complicated to illustrate this

my_mean2 <- function(xvec) {
	xvec_sum <- sum(xvec)
	xvec_n <- length(xvec)
	xvec_mean <- sum(xvec) / length(xvec)
	xvec_mean
}

my_mean2(x)

#notice only the last line is returned.



### linear regression
# change n and beta to explore pitfalls of p values

n <- 25
pred1 <- rnorm(n)
x <- cbind(1, pred1)
b <- c(2, 3.3)

y <- x %*% b + rnorm(n)

plot(pred1, y)

mod <- lm(y ~ pred1)
summary(mod)

abline(mod)



### principles of debugging
# PREVENT BUGS
# 	-write small chuncks of code and test test test
#	-write testers along the way
# IDENTIFYING BUGS
#	-realize there is a bug (test test test)
#	-isolate the source (run code line by line)
#	-identify the bug and fix it
#	-test test test
# EXAMPLE
# TDBANK first ATM machines
# work through a bug.