## Getting an R dataset to play with
library(datasets)
data(iris)
summary(iris)

## Getting the plotting library of choice
## install.packages("ggplot2")
library(ggplot2)

# Plot Sepal.length against Petal.Length
ggplot(iris, aes(x=Sepal.Length, y = Petal.Length)) +
  geom_point()

# Can colour by species to see differences
ggplot(iris, aes(x=Sepal.Length, y = Petal.Length, color = Species)) +
  geom_point()

# Need labels
ggplot(iris, aes(x=Sepal.Length, y = Petal.Length, color = Species)) +
  geom_point() +
  labs(x="Sepal Length (mm)", y = "Petal Length (mm)")

# Publications HATE coloured backgrounds
ggplot(iris, aes(x=Sepal.Length, y = Petal.Length, color = Species)) +
  geom_point() +
  labs(x="Sepal Length (mm)", y = "Petal Length (mm)") +
  theme_bw() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour="black"))

# It looks bad having data beyond the x- or y-axis limits
ggplot(iris, aes(x=Sepal.Length, y = Petal.Length, color = Species)) +
  geom_point() +
  labs(x="Sepal Length (mm)", y = "Petal Length (mm)") +
  scale_x_continuous(limits=c(4,8)) +
  scale_y_continuous(limits=c(0,8)) +
  theme_bw() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour="black"))

# It is SUPER expensive to print colour figures in journals, always default to black and white
ggplot(iris, aes(x=Sepal.Length, y = Petal.Length, color = Species, shape = Species)) +
  geom_point() +
  labs(x="Sepal Length (mm)", y = "Petal Length (mm)") +
  scale_x_continuous(limits=c(4,8)) +
  scale_y_continuous(limits=c(0,8)) +
  scale_colour_manual(values = c("black", "grey", "black")) +
  scale_shape_manual(values = c(16, 16, 0)) +
  theme_bw() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour="black"))

# You can also control elements of the legend (e.g., title, and test names)
ggplot(iris, aes(x=Sepal.Length, y = Petal.Length, color = Species, shape = Species)) +
  geom_point() +
  labs(x="Sepal Length (mm)", y = "Petal Length (mm)") +
  scale_x_continuous(limits=c(4,8)) +
  scale_y_continuous(limits=c(0,8)) +
  scale_colour_manual(name="Species Sampled", 
                      labels = c("Iris setosa", "Iris versicolor", "Iris virginica"),
                      values = c("black", "grey", "black")) +
  scale_shape_manual(name = "Species Sampled", 
                     labels = c("Iris setosa", "Iris versicolor", "Iris virginica"),
                     values = c(16, 16, 0)) +
  theme_bw() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour="black"))
