## Getting an R dataset to play with
library(datasets)
data(iris)
summary(iris)

## Getting the plotting library of choice
## install.packages("ggplot2")
library(ggplot2)

# Plot Sepal.length for each species
ggplot(iris, aes(Species, Sepal.Length, fill = Species)) +
  geom_boxplot() 

# Adding labels, removing background
ggplot(iris, aes(Species, Sepal.Length, fill = Species)) +
  geom_boxplot() +
  labs(x="Species Samples", y = "Sepal Length (mm)") +
  theme_bw() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour="black"))

# Adding whiskers and fixing y-axis scale
ggplot(iris, aes(Species, Sepal.Length, fill = Species)) +
  stat_boxplot(geom = "errorbar", width = 0.5) +
  geom_boxplot() +
  labs(x="Species Sampled", y = "Sepal Length (mm)") +
  scale_y_continuous(limits=c(4,8)) +
  theme_bw() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour="black"))

# Controlling x-axis labels
ggplot(iris, aes(Species, Sepal.Length, fill = Species)) +
  stat_boxplot(geom = "errorbar", width = 0.5) +
  geom_boxplot() +
  labs(x="Species Sampled", y = "Sepal Length (mm)") +
  scale_y_continuous(limits=c(4,8)) +
  scale_x_discrete(labels=c("I. setosa", "I. versicolor", "I. virginica")) +
  theme_bw() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour="black"))

# Removing Legend
ggplot(iris, aes(Species, Sepal.Length, fill = Species)) +
  stat_boxplot(geom = "errorbar", width = 0.5) +
  geom_boxplot() +
  labs(x="Species Sampled", y = "Sepal Length (mm)") +
  scale_y_continuous(limits=c(4,8)) +
  scale_x_discrete(labels=c("I. setosa", "I. versicolor", "I. virginica")) +
  theme_bw() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour="black"), 
        legend.position = "none")

# Controlling BoxPlot Colours
ggplot(iris, aes(Species, Sepal.Length, fill = Species)) +
  stat_boxplot(geom = "errorbar", width = 0.5) +
  geom_boxplot(fill="grey", color="black") +
  labs(x="Species Sampled", y = "Sepal Length (mm)") +
  scale_y_continuous(limits=c(4,8)) +
  scale_x_discrete(labels=c("I. setosa", "I. versicolor", "I. virginica")) +
  theme_bw() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour="black"), 
        legend.position = "none")
