## Deep-Sea Red Crab: Stable Isotope Analysis ##

# Set Working Directory
#setwd("~/Desktop/DataExpeditions/RedCrabCasestudy/DietAnalysis")
library(ggplot2)

#######################################
### Visualizing Stable Isotope Data ###
#######################################

# Read in the CSV file with the delta-13-C data
sidata <- as.data.frame(read.csv("Data/CrabCarbon.csv", header = TRUE, sep = ","))

# Make Sites the factor we are comparing
Sites <- as.factor(sidata$Site)

# delta-13-C for each individual crab, at each site.
ggplot(sidata, aes(x=CrabID, y=delta13C))+
  geom_point(aes(shape = Sites, color = Sites))


########################
### Calculating Diet ###
######################## 

# Read in CSV with our end members
end <- as.data.frame(read.csv("Data/EndMembers.csv", header = TRUE, sep = ","))

# Calculating proportion of diet originating from chemosynthetic carbon sources
##### EQUATION: CrabCarbon = (SeepCarbon x f-seep) + (OceanCarbon x (1-f-seep)) ####
##### EQUATION: (CrabCarbon - OceanCarbon) = (SeepCarbon x f-seep) - (OceanCarbon x f-seep)
##### EQUATION: f-seep = (CrabCarbon - OceanCarbon) / (SeepCarbon - OceanCarbon)
# where f-seep is the proportion of the diet originating from chemosynthetic carbon sources

# Adding empty columns to "sidata" to hold calculation values
namevector <- c("min", "mean", "max")
sidata[,namevector] <- NA

## Min% - will have lowest chemosynthetic delta13C and lowest POC delta13C value
## Mean% - will have the middle values for each end member
## Max % - will have highest chemosynthetic delta13C and highest POC delta13C value

# Calculation for Site 1
for (i in 1:40){                                                        # Every number in the sequence 1:40 is given the value 'i' in turn
  sidata[i,4] <- ((sidata[i,3] - end[3,2]) / (end[2,2] - end[3,2]))*100 # Row 'i' column 4 - calculating 'Min%' for Site 1
  sidata[i,5] <- ((sidata[i,3] - end[3,3]) / (end[2,3] - end[3,3]))*100 # Row 'i' column 4 - calculating 'Mean%'for Site 1
  sidata[i,6] <- ((sidata[i,3] - end[3,4]) / (end[2,4] - end[3,4]))*100 # Row 'i' column 4 - calculating 'Max%' for Site 1
}

# Calculation for Site 2
for (i in 41:80){                                                       # Every number in the sequence 41:80 is given the value 'i' in turn
  sidata[i,4] <- ((sidata[i,3] - end[3,2]) / (end[1,2] - end[3,2]))*100 # Row 'i' column 4 - calculating 'Min%' for Site 2
  sidata[i,5] <- ((sidata[i,3] - end[3,3]) / (end[1,3] - end[3,3]))*100 # Row 'i' column 4 - calculating 'Mean%'for Site 2
  sidata[i,6] <- ((sidata[i,3] - end[3,4]) / (end[1,4] - end[3,4]))*100 # Row 'i' column 4 - calculating 'Max%' for Site 2
}

# Plot Site 1 vs. Site 2: mean % of diet from chemosynthetic carbon sources
boxplot(mean~Site, data=sidata)

# Can test if the difference between the populations is significant
t.test(mean~Site, data=sidata)
# t = -16.98, df = 49.15, p < 0.001

##############################################################################################################
# Homework: edit the plot so that it is publication standard and 
#           explain the results in terms of ecology and food availability (1 or 2 Paragraphs, with citations)
##############################################################################################################

## With the boxplot you can:
##### Add axis Labels
##### Re-orientate numbers on y-axis
##### Change x-axis to show site names

## With the scatterplot you should:
##### Edit axis Labels
##### Reconfigure y-axis to include all the values
##### Remove background grey and reference lines
##### Remove background grey on legend and include site names
##### Add reference lines for POC, Chincoteague Mussels, and Shallp Canyon Mussels
##### Change the colours/marker shapes so that they are more appropriate for publication




