############################
### Pretty Scatter Plots ###
############################
library(ggplot2)

# Raw delta13C values for each individual crab
ggplot(sidata, aes(x=CrabID, y=delta13C)) +
  geom_point(aes(shape = Sites, color = Sites), size = 2) +
  scale_y_continuous(breaks=seq(-0,-80, -10)) +
  scale_colour_manual(name = "Sample Sites", 
                      labels = c("Shallop Canyon", "Chincoteague Seep"), 
                      values = c("black", "black")) +
  scale_shape_manual(name = "Sample Sites", 
                     labels = c("Shallop Canyon", "Chincoteague Seep"), 
                     values = c(19,1)) +
  geom_hline(aes(yintercept = -21, linetype="1"), colour = "grey") + 
  geom_hline(aes(yintercept = -62, linetype="2"), colour = "grey") +
  geom_hline(aes(yintercept = -70, linetype="3"), colour = "grey") +
  scale_linetype_manual(name = "Carbon Source δ13C Values",
                        labels= c("Particulate Organic Carbon","Shallop Canyon Mussels","Chincoteague Mussels"),
                        values = c(1,2,3)) +
  labs(x = "Individual Crab IDs", y = "δ13C (‰)") +
  theme(panel.background = element_blank(), axis.line = element_line(colour = "black"),
        legend.key = element_rect(colour = "white", fill = NA))

###### Pretty Box Plot ####### 
ggplot(sidata, aes(x = Sites, y = mean)) +
  stat_boxplot(geom = "errorbar", width = 0.5) +
  geom_boxplot() +
  scale_y_continuous(breaks = seq(0, 60, 10)) +
  scale_x_discrete(breaks=c("1","2"),
                   labels=c("Shallop Canyon", "Chincoteague Seep")) +
  xlab("Samples Sites") +
  ylab(expression(atop("% of Chemosynthetically Derived", paste("Carbon in Diet")))) +
  theme(panel.background = element_blank(), axis.line = element_line(colour = "black"))




# % of diet from chemosynthetically sourced carbon for each individual crab
ymin <- sidata[,4]
ymax <- sidata[,6]

ggplot(sidata, aes(x=CrabID, y=mean)) +
  geom_errorbar(aes(ymin = ymin, ymax = ymax)) +
  geom_point(aes(shape = Sites, color = Sites), size = 2) +
  ylim(NA, 80) +
  scale_colour_manual(labels = c("Shallop Canyon", "Chincoteague Seep"), 
                      values = c("black", "grey")) +
  scale_shape_manual(labels = c("Shallop Canyon", "Chincoteague Seep"), 
                     values = c(19,19)) +
  xlab("Individual Crab IDs") +
  ylab(expression(atop("% of Chemosynthetically Derived", paste("Carbon in Diet")))) +
  theme(panel.background = element_blank(), axis.line = element_line(colour = "black"),
        legend.key = element_rect(colour = "white", fill = NA),
        legend.position = "top", legend.title = element_blank())







boxplot(mean~Site, data = sidata, xlab = "Sample Sites", ylab = "% of Chemosynthetically Derived
        Carbon in Diet", names = c("Shallop Canyon", "Chincoteague Seep"))
