# data expeditions November 2017

# install.packages("SIBER")
library(SIBER)

# load data and make a new data frame in the format that SIBER expects
iso <- read.table("data/masteriso_dataexp.csv", header = TRUE, sep = ',')
iso_siber_df <- data.frame(iso1 = iso$d13C, iso2 = iso$d15N, group = iso$id, community = as.numeric(iso$ocean))

# find any row that has an NA in it and remove those lines
kill <- -which(is.na(iso_siber_df[, 1]))
iso_siber_df <- iso_siber_df[kill, ]

# create a siber "object" and use the built in plotting functions
iso_siber <- createSiberObject(iso_siber_df)

# these are graphical settings for the siber plotting function
community.hulls.args <- list(col = 1, lty = 1, lwd = 1)
group.ellipses.args  <- list(n = 100, p.interval = 0.95, lty = 2, lwd = 1)
group.hull.args 	 <- list(lty = 2)

# plot the isotope biplot
par(tcl = 0.3, las = 1)
plotSiberObject(
	iso_siber,
	ax.pad 		= 1,
	hulls 		= FALSE, community.hulls.args,
	ellipses 	= TRUE , group.ellipses.args,
	group.hulls = FALSE, group.hull.args,
	bty 			= 'l',
	iso.order 	= c(1,2),
	points.order = c(1, 17),
	xlab = expression({delta}^13*C~'\u2030'),
	ylab = expression({delta}^15*N~'\u2030')
)
box()
axis(3, labels = FALSE)
axis(4, labels = FALSE)
legend("topleft", legend = c("Mediterranean", "W. North Atlantic"), pch = c(1, 17), bty = 'n')

# calculate the standard ellipse size
community.ML <- communityMetricsML(iso_siber) 
print(community.ML)
group.ML <- groupMetricsML(iso_siber)
print(group.ML)

# plot standard ellipse size for each individual
par(mar = c(4.1, 5.1, 2, 2))
plot(group.ML[3, ], las = 1, type = 'n', xaxt = 'n', xlab = "", ylab = expression('standard ellipse area \u2030'^2))
plotdims <- par()$usr
rect(10.5, 0, plotdims[2], plotdims[4], col = "grey", border = NA) 
abline(v = 10.5, lty = 2)
points(group.ML[3, ], pch = 16)
labs <- c(paste0("MS", 1:10), paste0("WNA", 1:13))
axis(1, labels = labs, at = 1:length(labs), las = 2)
box()

legend("topleft", legend = "Mediterranean", bty = 'n')
legend("topright", legend = "Western North Atlantic", bty = 'n')